<?php

/**
 * This is the model class for table "host".
 *
 * The followings are the available columns in table 'host':
 * @property string $hostid
 * @property string $hoststatuscode
 * @property string $hostcategoryid
 * @property string $hostlocationid
 * @property string $hostcode
 * @property string $hostdesc
 * @property integer $hostcapacity
 * @property string $hostcoordinate
 *
 * The followings are the available model relations:
 * @property Bill[] $bills
 * @property Hostcategory $hostcategory
 * @property Hostlocation $hostlocation
 * @property Hoststatus $hoststatuscode0
 * @property Hostwo[] $hostwos
 */
class Host extends CActiveRecord {
    
    public $billno;

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Host the static model class
     */
    public static function model($className=__CLASS__) {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'host';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('hoststatuscode, hostcategoryid, hostlocationid, hostcode, hostcoordinate', 'required'),
            array('hostcapacity', 'numerical', 'integerOnly' => true),
            array('hoststatuscode, hostcode, hostcoordinate', 'length', 'max' => 25),
            array('hostdesc', 'length', 'max' => 75),
            array('billno', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('hostid, hoststatuscode, hostcategoryid, hostlocationid, hostcode, hostdesc, hostcapacity, hostcoordinate', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'bills' => array(self::HAS_MANY, 'Bill', 'hostid'),
            'hostcategory' => array(self::BELONGS_TO, 'Hostcategory', 'hostcategoryid'),
            'hostlocation' => array(self::BELONGS_TO, 'Hostlocation', 'hostlocationid'),
            'hoststatuscode0' => array(self::BELONGS_TO, 'Hoststatus', 'hoststatuscode'),
            'hostwos' => array(self::HAS_MANY, 'Hostwo', 'hostid'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'hostid' => Yii::t('host', 'hostid'),
            'hoststatuscode' => Yii::t('host', 'hoststatuscode'),
            'hostcategoryid' => Yii::t('host', 'hostcategoryid'),
            'hostlocationid' => Yii::t('host', 'hostlocationid'),
            'hostcode' => Yii::t('host', 'hostcode'),
            'hostdesc' => Yii::t('host', 'hostdesc'),
            'hostcapacity' => Yii::t('host', 'hostcapacity'),
            'hostcoordinate' => Yii::t('host', 'hostcoordinate'),
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search() {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('hostid', $this->hostid, true);
        $criteria->compare('hoststatuscode', $this->hoststatuscode, true);
        $criteria->compare('hostcategoryid', $this->hostcategoryid, true);
        $criteria->compare('hostlocationid', $this->hostlocationid, true);
        $criteria->compare('hostcode', $this->hostcode, true);
        $criteria->compare('hostdesc', $this->hostdesc, true);
        $criteria->compare('hostcapacity', $this->hostcapacity);
        $criteria->compare('hostcoordinate', $this->hostcoordinate, true);

        return new CActiveDataProvider($this, array(
                    'criteria' => $criteria,
                ));
    }

}