<?php

/**
 * This is the model class for table "hostlocation".
 *
 * The followings are the available columns in table 'hostlocation':
 * @property string $hostlocationid
 * @property string $hostlocationdesc
 * @property string $hostlocationimage
 * @property string $dimension
 *
 * The followings are the available model relations:
 * @property Host[] $hosts
 */
class Hostlocation extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Hostlocation the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'hostlocation';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('hostlocationdesc', 'length', 'max'=>75),
			array('dimension', 'length', 'max'=>25),
			array('hostlocationimage', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('hostlocationid, hostlocationdesc, hostlocationimage, dimension', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'hosts' => array(self::HAS_MANY, 'Host', 'hostlocationid'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'hostlocationid' => Yii::t('hostlocation', 'hostlocationid'),
			'hostlocationdesc' => Yii::t('hostlocation', 'hostlocationdesc'),
			'hostlocationimage' => Yii::t('hostlocation', 'hostlocationimage'),
			'dimension' => Yii::t('hostlocation', 'dimension'),
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('hostlocationid',$this->hostlocationid,true);
		$criteria->compare('hostlocationdesc',$this->hostlocationdesc,true);
		$criteria->compare('hostlocationimage',$this->hostlocationimage,true);
		$criteria->compare('dimension',$this->dimension,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}