<?php

/**
 * This is the model class for table "pic".
 *
 * The followings are the available columns in table 'pic':
 * @property string $picid
 * @property string $pictag
 * @property string $linktype
 * @property string $pictitle
 * @property string $picnote
 * @property string $linkno
 * @property string $picdata
 *
 * The followings are the available model relations:
 * @property Linktype $linktype0
 * @property Pictag $pictag0
 */
class Pic extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Pic the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'pic';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('picid', 'required'),
			array('picid, linkno', 'length', 'max'=>20),
			array('pictag, linktype', 'length', 'max'=>5),
			array('pictitle', 'length', 'max'=>50),
			array('picnote, picdata', 'safe'),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('picid, pictag, linktype, pictitle, picnote, linkno, picdata', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'linktype0' => array(self::BELONGS_TO, 'Linktype', 'linktype'),
			'pictag0' => array(self::BELONGS_TO, 'Pictag', 'pictag'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'picid' => Yii::t('pic', 'picid'),
			'pictag' => Yii::t('pic', 'pictag'),
			'linktype' => Yii::t('pic', 'linktype'),
			'pictitle' => Yii::t('pic', 'pictitle'),
			'picnote' => Yii::t('pic', 'picnote'),
			'linkno' => Yii::t('pic', 'linkno'),
			'picdata' => Yii::t('pic', 'picdata'),
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('picid',$this->picid,true);
		$criteria->compare('pictag',$this->pictag,true);
		$criteria->compare('linktype',$this->linktype,true);
		$criteria->compare('pictitle',$this->pictitle,true);
		$criteria->compare('picnote',$this->picnote,true);
		$criteria->compare('linkno',$this->linkno,true);
		$criteria->compare('picdata',$this->picdata,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}