<?php

/**
 * This is the model class for table "so".
 *
 * The followings are the available columns in table 'so':
 * @property string $sono
 * @property string $shipid
 * @property string $crcid
 * @property string $empid
 * @property string $reftype
 * @property string $topid
 * @property string $taxid
 * @property string $whid
 * @property string $tstatus
 * @property string $srepid
 * @property string $custid
 * @property string $termtype
 * @property string $perid
 * @property string $refrid
 * @property string $fobid
 * @property string $sotype
 * @property string $branchid
 * @property string $sodate
 * @property string $reqdtime
 * @property string $soexpdate
 * @property string $docno
 * @property string $custpono
 * @property string $billto
 * @property string $shipto
 * @property string $shipdtime
 * @property integer $duedays
 * @property integer $discdays
 * @property string $earlydisc
 * @property string $latecharge
 * @property boolean $istaxed
 * @property boolean $taxinc
 * @property string $excrate
 * @property string $fisrate
 * @property string $costtot
 * @property string $subtotal
 * @property string $discexp
 * @property string $discamt
 * @property string $taxamt
 * @property string $freight
 * @property string $others
 * @property string $total
 * @property string $sonote
 * @property string $sostatus
 * @property boolean $active
 * @property boolean $isautogen
 * @property string $refno
 * @property string $chkby
 * @property string $aprby
 * @property string $crtby
 * @property string $crtdate
 * @property string $updby
 * @property string $upddate
 * @property string $syncdate
 * @property boolean $_xt
 * @property boolean $islocked
 * @property boolean $isdraft
 * @property string $basesubtotal
 * @property string $basetaxamt
 * @property string $basediscamt
 * @property string $basetotal
 * @property string $basftaxamt
 * @property string $dpayment
 * @property string $version
 * @property boolean $ismemorized
 * @property string $memorizednote
 * @property string $printcount
 *
 * The followings are the available model relations:
 * @property Bill[] $bills
 * @property Cons[] $cons
 * @property Deo[] $deos
 * @property Jobcard[] $jobcards
 * @property Mfg[] $mfgs
 * @property Sod[] $sods
 * @property Deli[] $delis
 * @property Sale[] $sales
 * @property Branch $branch
 * @property Crc $crc
 * @property Emp $emp
 * @property Fob $fob
 * @property Per $per
 * @property Reftype $reftype0
 * @property Ship $ship
 * @property Sotype $sotype0
 * @property Srep $srep
 * @property Tax $tax
 * @property Termtype $termtype0
 * @property Top $top
 * @property Tstatus $tstatus0
 * @property Wh $wh
 * @property Bp $refr
 * @property Bp $cust
 * @property Sale[] $sales1
 * @property Wod[] $wods
 * @property Wo[] $wos
 */
class So extends CActiveRecord {

    public $billno;

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return So the static model class
     */
    public static function model($className=__CLASS__) {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'so';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('srepid, billno, crtby, updby', 'required'),
            array('duedays, discdays', 'numerical', 'integerOnly' => true),
            array('sono, empid, custid, refrid, earlydisc, latecharge, discexp, refno', 'length', 'max' => 15),
            array('shipid, srepid, chkby, aprby, crtby, updby, billno', 'length', 'max' => 10),
            array('crcid, reftype, topid, taxid, perid, fobid, sotype, branchid', 'length', 'max' => 5),
            array('whid', 'length', 'max' => 3),
            array('tstatus, termtype', 'length', 'max' => 1),
            array('docno, custpono', 'length', 'max' => 20),
            array('excrate, fisrate, costtot, subtotal, discamt, taxamt, freight, others, total, basesubtotal, basetaxamt, basediscamt, basetotal, basftaxamt, dpayment', 'length', 'max' => 19),
            array('sostatus', 'length', 'max' => 2),
            array('sodate, reqdtime, soexpdate, billto, shipto, shipdtime, istaxed, taxinc, sonote, active, isautogen, crtdate, upddate, syncdate, _xt, islocked, isdraft, version, ismemorized, memorizednote, printcount', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('sono, shipid, crcid, empid, reftype, topid, taxid, whid, tstatus, srepid, custid, termtype, perid, refrid, fobid, sotype, branchid, sodate, reqdtime, soexpdate, docno, custpono, billto, shipto, shipdtime, duedays, discdays, earlydisc, latecharge, istaxed, taxinc, excrate, fisrate, costtot, subtotal, discexp, discamt, taxamt, freight, others, total, sonote, sostatus, active, isautogen, refno, chkby, aprby, crtby, crtdate, updby, upddate, syncdate, _xt, islocked, isdraft, basesubtotal, basetaxamt, basediscamt, basetotal, basftaxamt, dpayment, version, ismemorized, memorizednote, printcount', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'bills' => array(self::MANY_MANY, 'Bill', 'billso(sono, billno)'),
            'cons' => array(self::MANY_MANY, 'Cons', 'socons(sono, consno)'),
            'deos' => array(self::MANY_MANY, 'Deo', 'sodeo(sono, deono)'),
            'jobcards' => array(self::HAS_MANY, 'Jobcard', 'sono'),
            'mfgs' => array(self::HAS_MANY, 'Mfg', 'sono'),
            'sods' => array(self::HAS_MANY, 'Sod', 'sono'),
            'delis' => array(self::MANY_MANY, 'Deli', 'sodeli(sono, delino)'),
            'sales' => array(self::MANY_MANY, 'Sale', 'sosale(sono, saleno)'),
            'branch' => array(self::BELONGS_TO, 'Branch', 'branchid'),
            'crc' => array(self::BELONGS_TO, 'Crc', 'crcid'),
            'emp' => array(self::BELONGS_TO, 'Emp', 'empid'),
            'fob' => array(self::BELONGS_TO, 'Fob', 'fobid'),
            'per' => array(self::BELONGS_TO, 'Per', 'perid'),
            'reftype0' => array(self::BELONGS_TO, 'Reftype', 'reftype'),
            'ship' => array(self::BELONGS_TO, 'Ship', 'shipid'),
            'sotype0' => array(self::BELONGS_TO, 'Sotype', 'sotype'),
            'srep' => array(self::BELONGS_TO, 'Srep', 'srepid'),
            'tax' => array(self::BELONGS_TO, 'Tax', 'taxid'),
            'termtype0' => array(self::BELONGS_TO, 'Termtype', 'termtype'),
            'top' => array(self::BELONGS_TO, 'Top', 'topid'),
            'tstatus0' => array(self::BELONGS_TO, 'Tstatus', 'tstatus'),
            'wh' => array(self::BELONGS_TO, 'Wh', 'whid'),
            'refr' => array(self::BELONGS_TO, 'Bp', 'refrid'),
            'cust' => array(self::BELONGS_TO, 'Bp', 'custid'),
            'sales1' => array(self::HAS_MANY, 'Sale', 'sono'),
            'wods' => array(self::HAS_MANY, 'Wod', 'sono'),
            'wos' => array(self::HAS_MANY, 'Wo', 'sono'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'sono' => Yii::t('so', 'sono'),
            'shipid' => Yii::t('so', 'shipid'),
            'crcid' => Yii::t('so', 'crcid'),
            'empid' => Yii::t('so', 'empid'),
            'reftype' => Yii::t('so', 'reftype'),
            'topid' => Yii::t('so', 'topid'),
            'taxid' => Yii::t('so', 'taxid'),
            'whid' => Yii::t('so', 'whid'),
            'tstatus' => Yii::t('so', 'tstatus'),
            'srepid' => Yii::t('so', 'srepid'),
            'custid' => Yii::t('so', 'custid'),
            'termtype' => Yii::t('so', 'termtype'),
            'perid' => Yii::t('so', 'perid'),
            'refrid' => Yii::t('so', 'refrid'),
            'fobid' => Yii::t('so', 'fobid'),
            'sotype' => Yii::t('so', 'sotype'),
            'branchid' => Yii::t('so', 'branchid'),
            'sodate' => Yii::t('so', 'sodate'),
            'reqdtime' => Yii::t('so', 'reqdtime'),
            'soexpdate' => Yii::t('so', 'soexpdate'),
            'docno' => Yii::t('so', 'docno'),
            'custpono' => Yii::t('so', 'custpono'),
            'billto' => Yii::t('so', 'billto'),
            'shipto' => Yii::t('so', 'shipto'),
            'shipdtime' => Yii::t('so', 'shipdtime'),
            'duedays' => Yii::t('so', 'duedays'),
            'discdays' => Yii::t('so', 'discdays'),
            'earlydisc' => Yii::t('so', 'earlydisc'),
            'latecharge' => Yii::t('so', 'latecharge'),
            'istaxed' => Yii::t('so', 'istaxed'),
            'taxinc' => Yii::t('so', 'taxinc'),
            'excrate' => Yii::t('so', 'excrate'),
            'fisrate' => Yii::t('so', 'fisrate'),
            'costtot' => Yii::t('so', 'costtot'),
            'subtotal' => Yii::t('so', 'subtotal'),
            'discexp' => Yii::t('so', 'discexp'),
            'discamt' => Yii::t('so', 'discamt'),
            'taxamt' => Yii::t('so', 'taxamt'),
            'freight' => Yii::t('so', 'freight'),
            'others' => Yii::t('so', 'others'),
            'total' => Yii::t('so', 'total'),
            'sonote' => Yii::t('so', 'sonote'),
            'sostatus' => Yii::t('so', 'sostatus'),
            'active' => Yii::t('so', 'active'),
            'isautogen' => Yii::t('so', 'isautogen'),
            'refno' => Yii::t('so', 'refno'),
            'chkby' => Yii::t('so', 'chkby'),
            'aprby' => Yii::t('so', 'aprby'),
            'crtby' => Yii::t('so', 'crtby'),
            'crtdate' => Yii::t('so', 'crtdate'),
            'updby' => Yii::t('so', 'updby'),
            'upddate' => Yii::t('so', 'upddate'),
            'syncdate' => Yii::t('so', 'syncdate'),
            '_xt' => Yii::t('so', '_xt'),
            'islocked' => Yii::t('so', 'islocked'),
            'isdraft' => Yii::t('so', 'isdraft'),
            'basesubtotal' => Yii::t('so', 'basesubtotal'),
            'basetaxamt' => Yii::t('so', 'basetaxamt'),
            'basediscamt' => Yii::t('so', 'basediscamt'),
            'basetotal' => Yii::t('so', 'basetotal'),
            'basftaxamt' => Yii::t('so', 'basftaxamt'),
            'dpayment' => Yii::t('so', 'dpayment'),
            'version' => Yii::t('so', 'version'),
            'ismemorized' => Yii::t('so', 'ismemorized'),
            'memorizednote' => Yii::t('so', 'memorizednote'),
            'printcount' => Yii::t('so', 'printcount'),
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search() {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('sono', $this->sono, true);
        $criteria->compare('shipid', $this->shipid, true);
        $criteria->compare('crcid', $this->crcid, true);
        $criteria->compare('empid', $this->empid, true);
        $criteria->compare('reftype', $this->reftype, true);
        $criteria->compare('topid', $this->topid, true);
        $criteria->compare('taxid', $this->taxid, true);
        $criteria->compare('whid', $this->whid, true);
        $criteria->compare('tstatus', $this->tstatus, true);
        $criteria->compare('srepid', $this->srepid, true);
        $criteria->compare('custid', $this->custid, true);
        $criteria->compare('termtype', $this->termtype, true);
        $criteria->compare('perid', $this->perid, true);
        $criteria->compare('refrid', $this->refrid, true);
        $criteria->compare('fobid', $this->fobid, true);
        $criteria->compare('sotype', $this->sotype, true);
        $criteria->compare('branchid', $this->branchid, true);
        $criteria->compare('sodate', $this->sodate, true);
        $criteria->compare('reqdtime', $this->reqdtime, true);
        $criteria->compare('soexpdate', $this->soexpdate, true);
        $criteria->compare('docno', $this->docno, true);
        $criteria->compare('custpono', $this->custpono, true);
        $criteria->compare('billto', $this->billto, true);
        $criteria->compare('shipto', $this->shipto, true);
        $criteria->compare('shipdtime', $this->shipdtime, true);
        $criteria->compare('duedays', $this->duedays);
        $criteria->compare('discdays', $this->discdays);
        $criteria->compare('earlydisc', $this->earlydisc, true);
        $criteria->compare('latecharge', $this->latecharge, true);
        $criteria->compare('istaxed', $this->istaxed);
        $criteria->compare('taxinc', $this->taxinc);
        $criteria->compare('excrate', $this->excrate, true);
        $criteria->compare('fisrate', $this->fisrate, true);
        $criteria->compare('costtot', $this->costtot, true);
        $criteria->compare('subtotal', $this->subtotal, true);
        $criteria->compare('discexp', $this->discexp, true);
        $criteria->compare('discamt', $this->discamt, true);
        $criteria->compare('taxamt', $this->taxamt, true);
        $criteria->compare('freight', $this->freight, true);
        $criteria->compare('others', $this->others, true);
        $criteria->compare('total', $this->total, true);
        $criteria->compare('sonote', $this->sonote, true);
        $criteria->compare('sostatus', $this->sostatus, true);
        $criteria->compare('active', $this->active);
        $criteria->compare('isautogen', $this->isautogen);
        $criteria->compare('refno', $this->refno, true);
        $criteria->compare('chkby', $this->chkby, true);
        $criteria->compare('aprby', $this->aprby, true);
        $criteria->compare('crtby', $this->crtby, true);
        $criteria->compare('crtdate', $this->crtdate, true);
        $criteria->compare('updby', $this->updby, true);
        $criteria->compare('upddate', $this->upddate, true);
        $criteria->compare('syncdate', $this->syncdate, true);
        $criteria->compare('_xt', $this->_xt);
        $criteria->compare('islocked', $this->islocked);
        $criteria->compare('isdraft', $this->isdraft);
        $criteria->compare('basesubtotal', $this->basesubtotal, true);
        $criteria->compare('basetaxamt', $this->basetaxamt, true);
        $criteria->compare('basediscamt', $this->basediscamt, true);
        $criteria->compare('basetotal', $this->basetotal, true);
        $criteria->compare('basftaxamt', $this->basftaxamt, true);
        $criteria->compare('dpayment', $this->dpayment, true);
        $criteria->compare('version', $this->version, true);
        $criteria->compare('ismemorized', $this->ismemorized);
        $criteria->compare('memorizednote', $this->memorizednote, true);
        $criteria->compare('printcount', $this->printcount, true);

        return new CActiveDataProvider($this, array(
                    'criteria' => $criteria,
                ));
    }

    public function beforeSave() {
        if ($this->isNewRecord) {
            $ncount = new Ncount("SO");
            $this->sono = $ncount->exec();
            $this->active = true;
            $this->sodate = date('Y-m-d');
            $this->reftype = "PO";
            $this->whid = Reg::model()->getRegVal("WHSALE");
            $this->crtdate = date('Y-m-d H:i:s');
            $this->upddate = date('Y-m-d H:i:s');
            $this->custid = 'CASH';
            $this->perid = Per::model()->getPerActive();
            $this->crcid = Bpacc::model()->getCrcId($this->custid);
            $this->istaxed = Bp::model()->getSaleIsTaxed($this->custid);
            $this->taxinc = false;
            $this->termtype = 'R';
            $this->duedays = 14;
            $this->discdays = 0;
            $this->version = 1;

            if ($this->custid == 'CASH') {
                $this->billto = 'CASH';
                $this->shipto = 'CASH';
            }

            $crc = Crc::model()->findByPk($this->crcid);
            if ($crc != null) {
                $this->excrate = $crc->excrate;
                $this->fisrate = $crc->fisrate;
            }
        }

        return true;
    }

    public function spSo_New() {
        $sp = new SP('spSo_New', array($this->sono, $this->billno, true));
        $sp->exec();
    }
    
    public function calcSum(){
        $command = Yii::app()->db->createCommand('SELECT SUM(subtotal) as subtotal, SUM(basesubtotal) as basesubtotal, SUM(totaltaxamt) as totaltaxamt, SUM(basftotaltaxamt) as basftotaltaxamt, SUM(basetotaltaxamt) as basetotaltaxamt, SUM(totalscamt) as totalscamt FROM sod WHERE sono=:sono');
        $command->bindValue(':sono', $this->sono);
        $result= $command->queryRow();
        
        $this->subtotal = $result['subtotal'];
        $this->basesubtotal = $result['basesubtotal'];
        $this->scamt = $result['totalscamt'];
        $this->taxamt = $result['totaltaxamt'];
        $this->basftaxamt = $result['basftotaltaxamt'];
        $this->basetaxamt = $result['basetotaltaxamt'];
        
        TransactionCalculator::recalcMasterData($this);
        
        $this->save();
    }

}