<?php

/**
 * This is the model class for table "tax".
 *
 * The followings are the available columns in table 'tax':
 * @property string $taxid
 * @property string $accpurctax
 * @property string $accsaletax
 * @property string $taxname
 * @property string $taxexp
 * @property string $taxexpunreg
 *
 * The followings are the available model relations:
 * @property Bp[] $bps
 * @property Bp[] $bps1
 * @property Cretd[] $cretds
 * @property Cons[] $cons
 * @property Cret[] $crets
 * @property Consd[] $consds
 * @property Delid[] $dels
 * @property Deo[] $deos
 * @property Prcv[] $prcvs
 * @property Pod[] $pods
 * @property Po[] $pos
 * @property Prcvd[] $prcvds
 * @property Pretd[] $pretds
 * @property Purcdfa[] $purcdfas
 * @property Purcd[] $purcds
 * @property Purc[] $purcs
 * @property Saled[] $saleds
 * @property Saledfa[] $saledfas
 * @property Sod[] $sods
 * @property Sretd[] $sretds
 * @property Sret[] $srets
 * @property So[] $sos
 * @property Deod[] $deods
 * @property Sale[] $sales
 * @property Pret[] $prets
 * @property Taxrate[] $taxrates
 * @property Item[] $items
 * @property Item[] $items1
 * @property Acc $accsaletax0
 * @property Acc $accpurctax0
 */
class Tax extends CActiveRecord {

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Tax the static model class
     */
    public static function model($className=__CLASS__) {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName() {
        return 'tax';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules() {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('taxid', 'required'),
            array('taxid', 'length', 'max' => 5),
            array('accpurctax, accsaletax', 'length', 'max' => 10),
            array('taxname', 'length', 'max' => 50),
            array('taxexp, taxexpunreg', 'length', 'max' => 15),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('taxid, accpurctax, accsaletax, taxname, taxexp, taxexpunreg', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations() {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'bps' => array(self::HAS_MANY, 'Bp', 'purctaxid'),
            'bps1' => array(self::HAS_MANY, 'Bp', 'saletaxid'),
            'cretds' => array(self::HAS_MANY, 'Cretd', 'taxid'),
            'cons' => array(self::HAS_MANY, 'Cons', 'taxid'),
            'crets' => array(self::HAS_MANY, 'Cret', 'taxid'),
            'consds' => array(self::HAS_MANY, 'Consd', 'taxid'),
            'dels' => array(self::HAS_MANY, 'Delid', 'taxid'),
            'deos' => array(self::HAS_MANY, 'Deo', 'taxid'),
            'prcvs' => array(self::HAS_MANY, 'Prcv', 'taxid'),
            'pods' => array(self::HAS_MANY, 'Pod', 'taxid'),
            'pos' => array(self::HAS_MANY, 'Po', 'taxid'),
            'prcvds' => array(self::HAS_MANY, 'Prcvd', 'taxid'),
            'pretds' => array(self::HAS_MANY, 'Pretd', 'taxid'),
            'purcdfas' => array(self::HAS_MANY, 'Purcdfa', 'taxid'),
            'purcds' => array(self::HAS_MANY, 'Purcd', 'taxid'),
            'purcs' => array(self::HAS_MANY, 'Purc', 'taxid'),
            'saleds' => array(self::HAS_MANY, 'Saled', 'taxid'),
            'saledfas' => array(self::HAS_MANY, 'Saledfa', 'taxid'),
            'sods' => array(self::HAS_MANY, 'Sod', 'taxid'),
            'sretds' => array(self::HAS_MANY, 'Sretd', 'taxid'),
            'srets' => array(self::HAS_MANY, 'Sret', 'taxid'),
            'sos' => array(self::HAS_MANY, 'So', 'taxid'),
            'deods' => array(self::HAS_MANY, 'Deod', 'taxid'),
            'sales' => array(self::HAS_MANY, 'Sale', 'taxid'),
            'prets' => array(self::HAS_MANY, 'Pret', 'taxid'),
            'taxrates' => array(self::HAS_MANY, 'Taxrate', 'taxid'),
            'items' => array(self::HAS_MANY, 'Item', 'purctaxid'),
            'items1' => array(self::HAS_MANY, 'Item', 'saletaxid'),
            'accsaletax0' => array(self::BELONGS_TO, 'Acc', 'accsaletax'),
            'accpurctax0' => array(self::BELONGS_TO, 'Acc', 'accpurctax'),
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels() {
        return array(
            'taxid' => Yii::t('tax', 'taxid'),
            'accpurctax' => Yii::t('tax', 'accpurctax'),
            'accsaletax' => Yii::t('tax', 'accsaletax'),
            'taxname' => Yii::t('tax', 'taxname'),
            'taxexp' => Yii::t('tax', 'taxexp'),
            'taxexpunreg' => Yii::t('tax', 'taxexpunreg'),
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search() {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('taxid', $this->taxid, true);
        $criteria->compare('accpurctax', $this->accpurctax, true);
        $criteria->compare('accsaletax', $this->accsaletax, true);
        $criteria->compare('taxname', $this->taxname, true);
        $criteria->compare('taxexp', $this->taxexp, true);
        $criteria->compare('taxexpunreg', $this->taxexpunreg, true);

        return new CActiveDataProvider($this, array(
                    'criteria' => $criteria,
                ));
    }

    public function getTaxExp($taxid) {
        $model = self::model()->findByPk($taxid);
        if ($model != null) {
            return $model->taxexp;
        }else
            return null;
    }

}